==> micro_kernel-0.1.tar.gz: micro_kernel-0.1/net/net.h <==
/*
 * net.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * ͥåȥ̥إå
 */


#ifndef ne_net_h
#define ne_net_h


#include <sys/types.h>
#include <sys/ip.h>
#include <sys/socket.h>
#include <sys/AggregateList.h>
#include <netinet/in.h>
#include <kern/fs.h>
#include <kern/vm.h>
#include <kern/listFunc.h>
#include <net/SendBuf.h>


#ifndef ASM_FILE


enum{
	/* ͥ֡ */
	SOCK_CNCT_ON			= 1<<0,	/* ͥѤߡ */
	SOCK_CNCT_TRANS_FIN		= 1<<1,	/* ͥλ */
	SOCK_CNCT_RECV_FINACK	= 1<<2,	/* ͥλ */
	SOCK_CNCT_RECV_FIN		= 1<<3,	/* ͥλ */
	SOCK_LISTEN				= 1<<4,	/* åԤϡ */
	SOCK_DISCON_RECV		= 1<<5,	/* ͥǡ */
	SOCK_DISCON_SEND		= 1<<6,	/* ͥǡ */
	SOCK_LINK_ON			= 1<<7,	/* åȥ󥯺Ѥߡ */
};

// Хåե
typedef struct TRANS_BUF_INFO{
	char  *data[3];		/* ե졼ॢɥ쥹 */
	int    size[3];		/* ǡե졼ॵ */
	ushort type;		/* ե졼ॿס */
	uchar  ipType;		/* IPץȥ륿ס */
}TRANS_BUF_INFO;

// åȥץ
typedef struct{
	int	name;
}SOCK_OPT;

// IPץ
typedef struct{
	int name;
	int value;
}IP_OPT;

/*
 * Note!
 *  fsscΰ֤ϲۥե빽¤Τΰ֤ȥ󥯤ƤΤա
 */
typedef struct SOCKET{
	F_DSC			fd;				// եǥץ¤Ρ
	FS				*fs;			// FS¤Υɥ쥹
	struct SOCKET	*sc;			// åȥɥ쥹VENTRY¤Τinodeб롣
	uint16_t		sockType;		// åȥס
	uint16_t		stat;			// ͥ֡
	void			*sinf;			// SOCKET_INFO.
	AggregateList	recvBuf;		// Хåե
	AggregateList	recvStore;		// Receive buffer ¸
	void			*waitTask;		// Interrupt wait task.
	int				lockGate;		// åȥԥå

	// ipץȥ
	SOCK_OPT		sockOpt;		// åȥץ
	in_addr_t		dstip;			// Connection IP address.
	in_addr_t		srcip;			// Local host IP address.
	in_port_t		srcport;		// Source port number.
	in_port_t		dstport;		// Connection port number.
	IP_OPT			ipOpt;			// IPץ

	// tcpץȥ
	uint32_t		seqnum;			// ֹ
	uint32_t		acknum;			// ֹѥֹ
	uint32_t		remoteAck;		// ѥֹ
	uint			resend;			// ׵ᥫ
	struct SOCKET	*next;			// ͥ󥯡
	struct SOCKET	*prev;			// 
	uint16_t		mss;			// ͥȺ祵
	uint16_t		window;			// ͥ襦ɥ
	struct SOCKET	*waitNext;		// ͥǽԤ󥯡
	uint			waitTime;		// ǽԤϻms
	SEND_BUF		sendBuf;		// ǡХåե
	void			*listenTask;	// å󥿥
	struct SOCKET	*newsc_next;	// å󥳥ͥѥåȥ
}SOCKET;

typedef struct{
	// return : send size or error number
	int (*send)(SOCKET*, void*, size_t, int, struct sockaddr*);
	int (*recv)(SOCKET*, struct msghdr*);
	int (*connect)(SOCKET*);
	int (*shutdown)(SOCKET*, int);
	int (*listen)(SOCKET*, int);
	int (*accept)(SOCKET*, SOCKET**, uint32_t*);
	int (*poll)(SOCKET*, int);
}SOCKET_INFO;


extern inline uint16_t swapWord(ushort value)
{
	return (value>>8)+(value<<8);
}

extern inline uint32_t swapInt32(uint32_t value)
{
	return (value>>24)+((value>>8)&0xff00)+((value<<8)&0xff0000)+(value<<24);
}

extern ushort getEphemeralPort();
extern void closeSocket(SOCKET*);
extern int makeSocket(int,int,SOCKET**);
extern int sys_socket();
extern int sys_send();
extern int sys_sendmsg();
extern int sys_recv();
extern int sys_recvmsg();
extern int sys_connect();
extern int sys_shutdown();
extern int sys_bind();
extern int sys_listen();
extern int sys_accept();
extern int sys_getsockname();
extern int sys_getpeername();
extern int sys_getsockopt();
extern int sys_setsockopt();
extern int registSocket(SOCKET_INFO*,int);
extern int initNet();


#endif


#endif

==> micro_kernel-0.3.tar.gz: micro_kernel-0.3/net/net.h <==
/*
 * net.h
 *
 * Copyright 2004, Minoru Murashima. All rights reserved.
 * Distributed under the terms of the BSD License.
 *
 * ͥåȥ̥إå
 */


#ifndef ne_net_h
#define ne_net_h


#include <sys/types.h>
#include <sys/ip.h>
#include <sys/socket.h>
#include <lib/AggregateList.h>
#include <netinet/in.h>
#include <kern/fs.h>
#include <kern/vm.h>
#include <net/SendBuf.h>


#ifndef ASM_FILE


enum{
	/* ͥ֡ */
	SOCK_CNCT_ON			= 1<<0,	/* ͥѤߡ */
	SOCK_CNCT_TRANS_FIN		= 1<<1,	/* ͥλ */
	SOCK_CNCT_RECV_FINACK	= 1<<2,	/* ͥλ */
	SOCK_CNCT_RECV_FIN		= 1<<3,	/* ͥλ */
	SOCK_LISTEN				= 1<<4,	/* åԤϡ */
	SOCK_DISCON_RECV		= 1<<5,	/* ͥǡ */
	SOCK_DISCON_SEND		= 1<<6,	/* ͥǡ */
	SOCK_LINK_ON			= 1<<7,	/* åȥ󥯺Ѥߡ */
};

// Хåե
typedef struct TRANS_BUF_INFO{
	char  *data[3];		/* ե졼ॢɥ쥹 */
	int    size[3];		/* ǡե졼ॵ */
	ushort type;		/* ե졼ॿס */
	uchar  ipType;		/* IPץȥ륿ס */
}TRANS_BUF_INFO;

// åȥץ
typedef struct{
	int	name;
}SOCK_OPT;

// IPץ
typedef struct{
	int name;
	int value;
}IP_OPT;

/*
 * Note!
 *  fsscΰ֤ϲۥե빽¤Τΰ֤ȥ󥯤ƤΤա
 */
typedef struct SOCKET{
	F_DSC				fd;					// եǥץ¤Ρ
	FS					*fs;				// FS¤Υɥ쥹
	struct SOCKET		*sc;				// åȥɥ쥹VENTRY¤Τinodeб롣
	uint16_t			sockType;			// åȥס
	uint16_t			stat;				// ͥ֡
	void				*sinf;				// SOCKET_INFO.
	AggregateList		recvBuf;			// Хåե
	AggregateList		recvStore;			// Receive buffer ¸
	AggregateListMethod	recvStoreMethod;	// Receive buffer ¸᥽å
	void				*waitTask;			// Interrupt wait task.
	int					lockGate;			// åȥԥå

	// ipץȥ
	SOCK_OPT			sockOpt;			// åȥץ
	in_addr_t			dstip;				// Connection IP address.
	in_addr_t			srcip;				// Local host IP address.
	in_port_t			srcport;			// Source port number.
	in_port_t			dstport;			// Connection port number.
	IP_OPT				ipOpt;				// IPץ

	// tcpץȥ
	uint32_t			seqnum;				// ֹ
	uint32_t			acknum;				// ֹѥֹ
	uint32_t			remoteAck;			// ѥֹ
	uint				resend;				// ׵ᥫ
	struct SOCKET		*next;				// ͥ󥯡
	struct SOCKET		*prev;				// 
	uint16_t			mss;				// ͥȺ祵
	uint16_t			window;				// ͥ襦ɥ
	struct SOCKET		*waitNext;			// ͥǽԤ󥯡
	uint				waitTime;			// ǽԤϻms
	SEND_BUF			sendBuf;			// ǡХåե
	void				*listenTask;		// å󥿥
	struct SOCKET		*newsc_next;		// å󥳥ͥѥåȥ
}SOCKET;

typedef struct{
	// return : send size or error number
	int (*send)(SOCKET*, void*, size_t, int, struct sockaddr*);
	int (*recv)(SOCKET*, struct msghdr*);
	int (*connect)(SOCKET*);
	int (*shutdown)(SOCKET*, int);
	int (*listen)(SOCKET*, int);
	int (*accept)(SOCKET*, SOCKET**, uint32_t*);
	int (*poll)(SOCKET*, int);
}SOCKET_INFO;


extern inline uint16_t swapWord(ushort value)
{
	return (value>>8)+(value<<8);
}

extern inline uint32_t swapInt32(uint32_t value)
{
	return (value>>24)+((value>>8)&0xff00)+((value<<8)&0xff0000)+(value<<24);
}

extern ushort getEphemeralPort();
extern void closeSocket(SOCKET*);
extern int makeSocket(int,int,SOCKET**);
extern int sys_socket();
extern int sys_send();
extern int sys_sendmsg();
extern int sys_recv();
extern int sys_recvmsg();
extern int sys_connect();
extern int sys_shutdown();
extern int sys_bind();
extern int sys_listen();
extern int sys_accept();
extern int sys_getsockname();
extern int sys_getpeername();
extern int sys_getsockopt();
extern int sys_setsockopt();
extern int registSocket(SOCKET_INFO*,int);
extern int initNet();


#endif


#endif
